(point-cloud)=
# The georeferenced point cloud ({class}`~geoutils.PointCloud`)

Coming soon!

In the meantime, most point cloud operations (for instance in {ref}`raster-vector-point`) return a
{class}`~geoutils.Vector` with only point geometries and a specific `data_column_name` corresponding to the point
cloud values.
